Related projects
================

.. include:: includes/all.rst

* FDEunlock_ – Check and unlock full disk encrypted systems via ssh

* Mandos_ – System for allowing servers with encrypted root file systems to reboot unattended and/or remotely

* `Comparison of Mandos and FDEunlock <https://fdeunlock.readthedocs.io/en/latest/related_projects.html>`_

The following Ansible roles do the same thing as this role and have been
deprecated by this role:

* `systemli.rootcrypto <https://github.com/systemli/ansible-rootcrypto>`_
* `martin-v.sshpreluks <https://github.com/martin-v/ansible-sshpreluks>`_

Refer to :ref:`dropbear_initramfs__ref_migrating_from_other_roles` for details.
